#
# spec file for package tree
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tree
Version:        2.2.1
Release:        1.4
Summary:        File listing as a tree
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
URL:            https://oldmanprogrammer.net/tar/tree/
Source0:        https://oldmanprogrammer.net/tar/tree/%{name}-%{version}.tgz

%description
Tree is a recursive directory listing command that produces a depth
indented listing of files, which is colorized ala dircolors if the
LS_COLORS environment variable is set and output is to tty.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
export LDFLAGS="%{?_lto_cflags}"
%make_build

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 doc/%{name}.1 %{buildroot}%{_mandir}/man1
install -m 755 %{name} %{buildroot}%{_bindir}

%files
%license LICENSE
%doc CHANGES README
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Tue Nov 26 2024 Thomas Blume <Thomas.Blume@suse.com>
- update to 2.2.1
  * Fix regression where I free a pointer that should not have been freed due
    to a variable renaming that wasn't completed. (Daniel Li / Landon Bourma)
  * Put back, in a modified form, HTML href directory path fixing that was
    removed in 2.1.2. If the "baseHREF" part after the -H begins with a dash
    (-), the dash is removed and the lead directory name is removed from the
    href, otherwise it is left as-is.  It can be very difficult to know how to
    handle the host and directory part given the plethora of protocols and
    what-not, so hopefully this should give enough control over that to suit
    most requirements.
  Version 2.2.0 (11/24/2024)
  * Add option --opt-toggle which turns on the ability to toggle options such
    as -a, -p, etc.  Useful to add to an alias for turning an option off when
    using said alias. (Christoph Anton Mitterer)
  * Add --hyperlink option to print OSC 8 terminal hyperlinks for files. Also
    adds the --scheme and --authority options to modify the schema and hostname/
    authority of the links. (Nicolai Dagestad)
    OSC 8 Terminal hyperlinks:
    https://gist.github.com/egmontkob/eb114294efbcd5adb1944c9f3cb5feda
  * Maybe finally fix JSON error reporting when unable to open a directory and a
    full tree is required, such as when using --du. (Alchemyst@github)
  * Fix small rounding error in human readable size (-h) output, where 9.99K is
    rounded to 10.0K rather than 10K (Ivan Ivanovich)
  * Fix the totals report for sizes when --du option is used.  The directory
    size total was correct, but the final report was an accumulation of all
    the directory totals rather than just the top most directory total.
    (Alchemyst@github)
  * Add .gitignore file to distribution for those wanting that. (Kenta Arai)
  * Add 'none' as a valid --sort option (i.e. -U).
  * Add ability to cross compile for Android (freemedom@github)
  * List charsets again if --charsets is not given an argument.
  * Allow --help and usage to use ANSI bold and italic if colorization is
    enabled.
  * General code cleanups:
  - Removed unused externs where possible.
  - Clean up some warnings issued by -Wextra (Kenta Arai)
  - Update Makefile to allow CC and the CFLAGS -O3 option to be overridden,
    move CPPFLAGS into their own variable, add -Wstrict-prototypes
    (David Seifert)
  - Long over-due move to stdbool.h, removes custom bool type and changes all
    occurrences of TRUE/FALSE to true/false. (David Seifert / others)  This
    likely makes C99+ even more of a requirement now. Please let me know if
    this requires a work-around for your system.
  - Went ahead and added -Wconversion to the Makefile as well. This required a
    large number of type conversion fixing which may have unexpected side
    effects, but should hopefully help with tree safely dealing with absurd
    sizes/number of things in the future as this promotes using size_t more.
    This probably needs more work to do properly however.
  - Apply the const constraint on parameter strings wherever possible.
* Wed Sep 25 2024 Dirk Müller <dmueller@suse.com>
- update to 2.1.3:
  * Mostly a brown-paper bag release to fix the below
    regression and add a feature I forgot to add.
  * Fix regression in search() function that broke --fromfile
  * Allow the -L option to accept its parameter immediately
    (with no space) instead of requiring it be the next option
    word.
  * Fix issue where --gitignore does not think a pattern with
    a singular terminal '/' (indicating it matches only
    directories,) is a relative path.
  * Don't emit the error 'recursive, not followed' if when
    using -L, the depth would prevent descending anyway. This also
    fixes up a JSON output error (missing comma) when this happens.
  * Don't prematurely sort files/directories with
  - -from*file. (gitlab @jack6th)
  * Various seg-faults fixed
  - Make doubly sure that there is actually a previous path
    entry when reading from a tabbed file.
  - Make sure there is actually a file entity when applying
    the link info to it when reading fromfile using --fflinks.
  - Increase space for the path a little in listdir(), just
    to be sure.
  * Make sure that there is no topsort (--dirsfirst /
  - -filesfirst) if there is no basesort (-U).
  * Make sure gittrim() function can handle a null string.
* Tue Sep 24 2024 Giacomo Leidi <giacomo.leidi@suse.com>
- Source tarball URL was unresolvable, update it to the correct version based on
  https://gitlab.com/OldManProgrammer/unix-tree
* Thu Nov 30 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Build with openSUSE flags
* Fri Jun 16 2023 Jan Baier <jbaier@suse.com>
- tree 2.1.1:
  * Various spelling corrections.
  * Fix issue where following links while doing JSON output would lead to
    incorrect JSON output. (simonpmind)
  * Fix issue where .info patterns relative to the .info file that did not use
    a wildcard for matching the prefix were not matching files properly.
    (German Lashevich)
  * Added support for making trees from tab indented files (--fromtabfile)
    (gitlab @AvidSeeker), also cleaned up some other issues in the fromfile
    code.
  * Fix buffer overflow in listdir() when file names are allowed to be longer
    than 256 characters (like when using fromfile.) (Javier Jaramago Fernández)
  * If when attempting to open a .gitignore or .info file from a top level
    directory and failing, recursively check the parents for such a file.  This
    stops when successful at opening such a file. This behavior might in the
    future be modified to open all such files in all parents to until root is
    reached. (Damien Bezborodov) Note that this requires the use of realpath()
    which I think may be an issue for some OSes.
  * Fix issue where tree would never descend (-l) a symbolic link when a full
    tree is gathered (--du/matchdirs/prune) (gitlab @6ramr)
* Thu Feb 16 2023 Jan Baier <jbaier@suse.com>
- tree 2.1.0:
  * Add support for --info and --gitignore for the --fromfile option.
    (Suggested by Piotr Andruszkow)
  * Add options --infofile and --gitfile to load .info and .gitignore files
    explicitly.  Each implies --info or --gitignore respectively.
  * Add NULL guard for json_printinfo() and xml_printinfo() (and fix ftype
    printing for XML) (Kenta Arai)
  * Fix getcharset() to not return a getenv() pointer (fix for ENV34-C issue.)
    (Kenta Arai)
  * Another attempt at fixing extraneous /'s in HTML URLs/output. (Sebastian
    Rose)
  * Fixed XML output (Dave Rice)
  * Remove the (very outdated) French version of the manpage.  Look to
    localization projects such as Debian's 'manpages-l10n' for localized
    translations. (hmartink)
  * Add support for the NO_COLOR environment variable (https://no-color.org/).
    Equivalent to the -n option (can be still be overridden with -C).
    (Timm Fitschen)
  * Removed many C99isms to enable compiling on C90 compilers with fewer
    warnings.  (Sith Wijesinghe and Matthew Sessions)  It should not be
    necessary to avoid using a standard that is old enough to drink,
    furthermore it is all but impossible to remove the remaining warnings and
    have modern features like compound literals. In the meantime I've added
  - std=c11 to the default CFLAGS for Linux and will likely not worry about
    C90 compatibility going forward unless there is some other reason for it.
  * Added a helper function for long command line arguments to clean up option
    processing (and fixes the processing for a few of the options such as
  - -timefmt= (наб?).)
  * Added --hintro and --houtro options to select files to use as the HTML
    intro and outro.  Use /dev/null or an empty file to eliminate them
    entirely.  This should make it much easier to create your own custom CSS
    or embed one or more trees into a web page.
  * Defer printing the version until the character set is known so we can use
    the linedraw copyright symbol.
  * Revert change to the error code to not return an error (code 2) when
    attempting to list a non-directory that actually exists.  Tree will still
    return an error when attempting to list a non-existing directory/file.
  * Added option --fflinks which will process symbolic link information from
    a file generated with 'tree -if --noreport' when using --fromfile.
    (Suggested by Chentao Credungtao)
  * Updated the totals reporting code to also include in the total the file or
    directory that is being listed.  This should make a correct report when
    doing something like 'tree *'.
* Wed Sep  7 2022 Andreas Stieger <andreas.stieger@gmx.de>
- tree 2.0.4:
  * Fix missing comma in JSON output
* Sun Aug 28 2022 Andreas Stieger <andreas.stieger@gmx.de>
- tree 2.0.3:
  * Fix segfault when filelimit is used and tree encounters a
    directory it cannot enter
  * Fixed broken -x option (stops recursing.)
  * Fix use after free (causing segfault) for dir/subdir in list.c
  * Multiple fixes for .gitignore functionality
  * Fixed segfault when an unknown directory is given with -X
  * Fixed output up for -X and -J options
* Thu Feb 17 2022 Andreas Stieger <andreas.stieger@gmx.de>
- tree 2.0.2:
  * stddata option now requires STDDATA_FD to be set
  * Fix HTML url output issue
  * Fix an error with * in the patchmatch code where *foo*bar
    would match *foo alone
* Tue Jan  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- tree 2.0.1:
  * Make patterns ending in '/' match directories (but not files)
    for -I / -P, should also fix issues with --gitignore as well
  - Fix --gitignore not matching files relative to the path of the
    .gitignore
* Wed Dec 22 2021 Andreas Stieger <andreas.stieger@gmx.de>
- tree 2.0.0:
  * Simplified code
  * Adds --info to print information about files/directories from
    information found in .info files
  * In HTML output, comments show as mouse over tooltips
  * Output un-indented JSON on file descriptor 3 ("stddata")
    automatically if file descriptor 3 is present
  * Always HTML escape filenames in HTML output even when -C is used
  * Return a non-zero exit status if there is a failure to open any directory.
  * Added --gitignore option to filter out files specified by
    .gitignore files. (also reads $GIT_DIR/info/exclude if present.)
  * To facilitate gitignore, adds support for ** on pattern matching
    to allow /**/ to match a single /
  * Now also supports multiple -I and -P instances
  * Now prints meta data for the top level directory as well.
  * Properly sort --fromfile input
  * Make tree colorization use reset (rs code in dir_colors,)
    not normal color when resetting attributes
  * Honor -n (no color) even if the CLICOLOR_FORCE environment
    variable is set
  * Fix --sort option to not require =
  * Defer sorting for --du until the entire sub-directory tree has
    been processed.
  * Fix JSON string escaping such that it is not using the HTML
    escaping
  * Add --filesfirst option
  * XML/HTML/JSON output needs to be mutually exclusive, last
    command line switch wins
- drop tree-makefile.patch
* Mon Dec 10 2018 atoptsoglou@suse.com
  Update to 1.8.0:
  * Added an experimental --fromfile option (suggested by several people.)
    This may eventually be replaced or supplimented by a --fromjson option.
  * Added support for BSD's CLICOLOR and CLICOLOR_FORCE environment variables.
    (Suggested by Alyssa Ross)
  * Use strftime() exclusively when formatting date/time to respect locale.
  * Some man page fixes and cleanups curtsey of Kirill Kolyshkin
  * Update BINDIR in Makefile for MacOS X -- It is not allowed to install
    programs to /usr/bin on MacOS X any longer due to System Integrity
    Protection (SIP) (Shawn Mehan)
  * Misc patches from Jacob Wahlgren:
  - Improved command line switch error reporting.
  - Symbolic links not displayed if a -P pattern is active
  - Missing argument error reporting fixes on long format switches.
  * Fixed JSON output hanging commas (John Lane, Tad, others)
  * JSON size output ignored -h/--si flags (Wagner Camarao)
  * Fixed issue with malformed multibyte string handling. (Mantas
    Mikul&#279;nas)
  * Fixed issue where mbstowcs() fails to null terminate the string due to
    improper UTF-8 encoding leading to garbage being printed. (Nick Craig-Wood)
  * Found a bug where the wrong inode (and device) information would be printed
    for symbolic links. (Stephan Gabert)
  - adjust tree-makefile.patch
* Tue Jun 10 2014 tampakrap@opensuse.org
- Update to 1.7.0:
  * Allow user/group names up to 32 characters before clipping.
  * Made -i compress XML and JSON output as much as possible by eliminating
    extraneous whitespace.
  * Added --caseinsensitive (renamed --ignore-case ala grep) flag so patterns
    match without regard to case, courtesy of Jason A Donenfeld.
  * Added --matchdirs option courtesy of Brian Mattern & Jason A. Donenfeld
    <Jason@zx2c4.com>.
  * Fixed possible buffer overflow on large uid/gids w/o user names/group
    names (Alexandre Wendling <alexandrerw@celepar.pr.gov.br>)
  * Added JSON support courtesy of Florian Sesser <fs@it-agenten.com>.
  * Fixed formatting error with HTML output when -L 1 specified. (Sascha Zorn
    <sascha.zorn@gmail.com>)
  * Added file size sorting (Philipp M?ller <philippausmuensing@googlemail.com>)
  * Added '--sort[=]<name>' option, ala ls.
  * Fixed OS X makefile problems (Ryan Hollis <theryanhollis@gmail.com>)
  * Fixed possible memory overflow in read_dir (path/lbuf not equal in size
    to pathsize/lbufsize.) (Han Hui <hanhui03@163.com>)
  * Fix S_ISDOOR/S_IFDOOR spelling mistake for Solaris. (Tim Mooney
    <Tim.Mooney@ndsu.edu>)
  * Make tree more reliably detect UTF-8 locales. (Mantas Mikulnas
    <grawity@gmail.com> and others.)
  * Return non-zero exit status on option errors, print usage to stdout when
    not an error, add the posix '--' option terminator, Change -S description
    to mean CP437 (console) output codes, not ASCII. (Ivan Shmakov
    <oneingray@gmail.com>)
- Use upstream tarball instead of a custom one
- Adjust the makefile patch accordingly:
  - Rename tree-dontstrip.patch to tree-makefile.patch,
    since the upstream makefile does not include the strip flag anymore in that line
  - Fix the CFLAGS and LDFLAGS accordingly
- Run spec-cleaner
* Mon Nov 21 2011 chris@computersalat.de
- update to 1.6.0
  * Re-org of code into multiple files, split HTML and Unix listdir()
    into separate functions, various code cleanups and optimizations.
  * Fixed a memory leak in listdir() when memory was allocated early
    and not freed before function exit.
  * Fixed possible buffer overflow where symbolic links are followed.
  * Fixed links printing "argetm" before the name of the link when the
    LINK setting for DIR_COLORS is set to target
    (Markus Schnalke <meillo@marmaro.de>)
  * More fully support dir colors -- added support for su, sg, tw, ow,
    & st options (and "do" in theory).
  * Use the environment variable "TREE_COLORS" instead of "LS_COLORS"
    for color information if it exists.
  * Added --si flag to print filesizes in SI (powers of 1000) units
    (Ulrich Eckhardt)
  * Added -Q to quote filenames in double quotes. Does not override
  - N or -q.
  * Control characters are no longer printed in carrot notation, but as
    backslashed octal, ala ls, except for codes 7-13 which are printed
    as \a, \b, \t, \n, \v, \f and \r respectively. Spaces and
    backslashes are also now backslashed as per ls, for better input to
    scripts unless -Q is in use (where "'s are backslashed.)
    (Ujjwal Kumar)
  * Added -U for unsorted listings (directory order).
  * Added -c for sorting by last status change (ala ls -c).
  * --dirsfirst is now a meta-sort and does not override -c, -v, -r
    or -t, but is disabled by -U.
  * After many requests, added the ability to process the entire tree
    before emitting output. Used for the new options --du, which works
    like the du command: sums the amount of space under each directory
    and prints a total amount used in the report and the --prune option
    which will prune all empty directories from the output (makes the -P
    option output much more readable.) It should be noted that this will
    be slow to output when processing large directory trees and can
    consume copious amounts of memory, use at your own peril.
  * Added -X option to emit the directory tree in XML format
    (turns colorization off always.)
  * Added --timefmt option to specify the format of time display
    (implies -D). Uses the strftime format.
- rework donstrip patch
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Tue May  4 2010 meissner@suse.de
- pass in OPTFLAGS seperately, so LARGEFILE support does not
  get lost. bnc#601779
* Mon Dec  7 2009 chris@computersalat.de
- New upstream version 1.5.3
- cleanup spec
  * removed ^#----
- reworked dontstrip patch
* Tue Jul  7 2009 chris@computersalat.de
- added Changes, Author
* Fri Jul  3 2009 kay.sievers@novell.com
- New upstream version 1.5.2.2
  Added -v option for version sorting
* Sat Apr 14 2007 kay.sievers@suse.de
- New upstream version 1.5.1
- install README, LICENCE
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Aug 11 2005 kasievers@suse.de
- New version 1.5
* Tue Aug  9 2005 mmj@suse.de
- Use $RPM_OPT_FLAGS
* Sun Jan 18 2004 mmj@suse.de
- Fix compound statements (gcc 3.4)
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Don't strip explicitly
* Thu May 22 2003 coolo@suse.de
- use BuildRoot
* Tue Jan 14 2003 nadvornik@suse.cz
- fixed multi-line string literals
* Fri Jan  5 2001 jj@suse.de
- initial version
- gzipped manpage in archive
- removed binary from archive
- explicit install by specfile instead of 'make install'
